@@ -2,13 +2,13 @@ from dataclasses import dataclass
 
 import pandas
 
-from autofaker import autopandas, fakepandas, autodata
+from autofaker import autodata, autopandas, fakepandas
 
 
 class SimpleClassA:
     id = -1
-    name: 'test'
-    text = 'test'
+    name: "test"
+    text = "test"
 
 
 class SimpleClassB:
@@ -26,13 +26,16 @@ class SimpleClassC:
 
 # Anonymous Pandas DataFrame Via Decorator
 
+
 @autopandas(SimpleClassA)
 def test_create_anonymous_pandas_dataframe_returns_not_none(df: pandas.DataFrame):
     assert df is not None
 
 
 @autopandas(SimpleClassA, 10)
-def test_create_anonymous_pandas_dataframe_with_rowcount_returns_not_empty(df: pandas.DataFrame):
+def test_create_anonymous_pandas_dataframe_with_rowcount_returns_not_empty(
+    df: pandas.DataFrame,
+):
     assert len(df.index) != 0
 
 
@@ -42,7 +45,9 @@ def test_create_fake_pandas_dataframe_returns_not_none(df: pandas.DataFrame):
 
 
 @fakepandas(SimpleClassA, 10)
-def test_create_fake_pandas_dataframe_with_rowcount_returns_not_empty(df: pandas.DataFrame):
+def test_create_fake_pandas_dataframe_with_rowcount_returns_not_empty(
+    df: pandas.DataFrame,
+):
     assert len(df.index) != 0
 
 
@@ -53,13 +58,17 @@ def test_can_create_anonymous_pandas_dataframes(cls):
 
 
 @autopandas(SimpleClassB)
-def test_can_create_anonymous_pandas_dataframes_from_class_with_constructor_arguments(cls):
+def test_can_create_anonymous_pandas_dataframes_from_class_with_constructor_arguments(
+    cls,
+):
     print(cls)
     assert not cls.empty
 
 
 @autopandas(SimpleClassC)
-def test_can_create_anonymous_pandas_dataframes_from_class_with_constructor_class_arguments(cls):
+def test_can_create_anonymous_pandas_dataframes_from_class_with_constructor_class_arguments(
+    cls,
+):
     print(cls)
     assert not cls.empty
 
@@ -73,18 +82,23 @@ class DataClass:
 
 # Anonymous Pandas DataFrame Via Decorator From DataClass
 
+
 @autopandas(DataClass)
 def test_create_anonymous_pandas_dataframe_returns_not_none(df: pandas.DataFrame):
     assert df is not None
 
 
 @autopandas(DataClass, 10)
-def test_create_anonymous_pandas_dataframe_with_rowcount_returns_not_empty(df: pandas.DataFrame):
+def test_create_anonymous_pandas_dataframe_with_rowcount_returns_not_empty(
+    df: pandas.DataFrame,
+):
     assert len(df.index) != 0
 
 
 @fakepandas(DataClass, 10)
-def test_create_fake_pandas_dataframe_with_rowcount_returns_not_empty(df: pandas.DataFrame):
+def test_create_fake_pandas_dataframe_with_rowcount_returns_not_empty(
+    df: pandas.DataFrame,
+):
     assert len(df.index) != 0
 
 
@@ -95,12 +109,15 @@ def test_create_fake_pandas_dataframe_returns_not_none(df: pandas.DataFrame):
 
 # Autodata Decorator Ignores Pandas
 
+
 @autodata()
 def test_autodata_decorator_ignores_pandas_dataframe(df: pandas.DataFrame):
     assert df is None
 
 
 @autodata()
-def test_autodata_decorator_ignores_only_pandas_dataframe(text: str, df: pandas.DataFrame):
+def test_autodata_decorator_ignores_only_pandas_dataframe(
+    text: str, df: pandas.DataFrame
+):
     assert None is not text
     assert df is None
