@@ -1,7 +1,7 @@
 import unittest
 from abc import abstractmethod
 from dataclasses import dataclass
-from datetime import datetime, date
+from datetime import date, datetime
 from typing import List
 
 from autofaker import Autodata
