@@ -3,7 +3,7 @@ from dataclasses import dataclass
 
 import pandas
 
-from autofaker import autodata, fakedata, autopandas, fakepandas
+from autofaker import autodata, autopandas, fakedata, fakepandas
 
 
 @dataclass
@@ -29,9 +29,9 @@ def autopandas_test_method(df: pandas.DataFrame):
 
 
 class AnonymousPrimitivesViaDecoratorThrowsExceptionsTests(unittest.TestCase):
-
     def test_autodata_throws_error_when_decorating_non_testmethod(self):
         with self.assertRaises(NotImplementedError):
+
             class X:
                 @autodata(str, str, str)
                 def not_test_method(self):
@@ -41,6 +41,7 @@ class AnonymousPrimitivesViaDecoratorThrowsExceptionsTests(unittest.TestCase):
 
     def test_autodata_throws_error_when_used_without_arguments(self):
         with self.assertRaises(NotImplementedError):
+
             class X:
                 @autodata()
                 def not_test_method(self):
@@ -50,6 +51,7 @@ class AnonymousPrimitivesViaDecoratorThrowsExceptionsTests(unittest.TestCase):
 
     def test_autodata_throws_error_when_used_without_arguments_annotation(self):
         with self.assertRaises(ValueError):
+
             class X(unittest.TestCase):
                 @autodata()
                 def not_test_method(self, text, number, decimal):
@@ -59,6 +61,7 @@ class AnonymousPrimitivesViaDecoratorThrowsExceptionsTests(unittest.TestCase):
 
     def test_fakedata_throws_error_when_decorating_non_testmethod(self):
         with self.assertRaises(NotImplementedError):
+
             class X:
                 @fakedata(str, str, str)
                 def not_test_method(self):
@@ -68,6 +71,7 @@ class AnonymousPrimitivesViaDecoratorThrowsExceptionsTests(unittest.TestCase):
 
     def test_fakedata_throws_error_when_used_without_arguments(self):
         with self.assertRaises(NotImplementedError):
+
             class X:
                 @fakedata()
                 def not_test_method(self):
@@ -77,6 +81,7 @@ class AnonymousPrimitivesViaDecoratorThrowsExceptionsTests(unittest.TestCase):
 
     def test_fakedata_throws_error_when_used_without_arguments_annotation(self):
         with self.assertRaises(ValueError):
+
             class X(unittest.TestCase):
                 @fakedata()
                 def not_test_method(self, text, number, decimal):
@@ -87,10 +92,11 @@ class AnonymousPrimitivesViaDecoratorThrowsExceptionsTests(unittest.TestCase):
     def test_autopandas_throws_error_when_decorating_non_testmethod(self):
         class SimpleClass:
             id = -1
-            name = 'name'
-            text = 'test'
+            name = "name"
+            text = "test"
 
         with self.assertRaises(NotImplementedError):
+
             class X:
                 @autopandas(SimpleClass)
                 def not_test_method(self, df):
@@ -101,10 +107,11 @@ class AnonymousPrimitivesViaDecoratorThrowsExceptionsTests(unittest.TestCase):
     def test_fakepandas_throws_error_when_decorating_non_testmethod(self):
         class SimpleClass:
             id = -1
-            name = 'name'
-            text = 'test'
+            name = "name"
+            text = "test"
 
         with self.assertRaises(NotImplementedError):
+
             class X:
                 @fakepandas(SimpleClass)
                 def not_test_method(self, df):
