@@ -3,13 +3,13 @@ from dataclasses import dataclass
 
 import pandas
 
-from autofaker import autopandas, fakepandas, autodata
+from autofaker import autodata, autopandas, fakepandas
 
 
 class SimpleClassA:
     id = -1
-    name: 'test'
-    text = 'test'
+    name: "test"
+    text = "test"
 
 
 class SimpleClassB:
@@ -26,13 +26,16 @@ class SimpleClassC:
 
 
 class AnonymousPandasDataFrameViaDecoratorTests(unittest.TestCase):
-
     @autopandas(SimpleClassA)
-    def test_create_anonymous_pandas_dataframe_returns_not_none(self, df: pandas.DataFrame):
+    def test_create_anonymous_pandas_dataframe_returns_not_none(
+        self, df: pandas.DataFrame
+    ):
         self.assertIsNotNone(df)
 
     @autopandas(SimpleClassA, 10)
-    def test_create_anonymous_pandas_dataframe_with_rowcount_returns_not_empty(self, df: pandas.DataFrame):
+    def test_create_anonymous_pandas_dataframe_with_rowcount_returns_not_empty(
+        self, df: pandas.DataFrame
+    ):
         self.assertNotEqual(len(df.index), 0)
 
     @fakepandas(SimpleClassA)
@@ -40,7 +43,9 @@ class AnonymousPandasDataFrameViaDecoratorTests(unittest.TestCase):
         self.assertIsNotNone(df)
 
     @fakepandas(SimpleClassA, 10)
-    def test_create_fake_pandas_dataframe_with_rowcount_returns_not_empty(self, df: pandas.DataFrame):
+    def test_create_fake_pandas_dataframe_with_rowcount_returns_not_empty(
+        self, df: pandas.DataFrame
+    ):
         self.assertNotEqual(len(df.index), 0)
 
     @autopandas(SimpleClassA)
@@ -48,11 +53,15 @@ class AnonymousPandasDataFrameViaDecoratorTests(unittest.TestCase):
         self.assertIsNotNone(cls)
 
     @autopandas(SimpleClassB)
-    def test_can_create_anonymous_pandas_dataframes_from_class_with_constructor_arguments(self, cls):
+    def test_can_create_anonymous_pandas_dataframes_from_class_with_constructor_arguments(
+        self, cls
+    ):
         self.assertIsNotNone(cls)
 
     @autopandas(SimpleClassC)
-    def test_can_create_anonymous_pandas_dataframes_from_class_with_constructor_class_arguments(self, cls):
+    def test_can_create_anonymous_pandas_dataframes_from_class_with_constructor_class_arguments(
+        self, cls
+    ):
         self.assertIsNotNone(cls)
 
 
@@ -64,17 +73,22 @@ class DataClass:
 
 
 class AnonymousPandasDataFrameViaDecoratorFromDataClassTests(unittest.TestCase):
-
     @autopandas(DataClass)
-    def test_create_anonymous_pandas_dataframe_returns_not_none(self, df: pandas.DataFrame):
+    def test_create_anonymous_pandas_dataframe_returns_not_none(
+        self, df: pandas.DataFrame
+    ):
         self.assertIsNotNone(df)
 
     @autopandas(DataClass, 10)
-    def test_create_anonymous_pandas_dataframe_with_rowcount_returns_not_empty(self, df: pandas.DataFrame):
+    def test_create_anonymous_pandas_dataframe_with_rowcount_returns_not_empty(
+        self, df: pandas.DataFrame
+    ):
         self.assertNotEqual(len(df.index), 0)
 
     @fakepandas(DataClass, 10)
-    def test_create_fake_pandas_dataframe_with_rowcount_returns_not_empty(self, df: pandas.DataFrame):
+    def test_create_fake_pandas_dataframe_with_rowcount_returns_not_empty(
+        self, df: pandas.DataFrame
+    ):
         self.assertNotEqual(len(df.index), 0)
 
     @fakepandas(DataClass)
@@ -83,12 +97,13 @@ class AnonymousPandasDataFrameViaDecoratorFromDataClassTests(unittest.TestCase):
 
 
 class AutodataDecoratorIgnoresPandas(unittest.TestCase):
-
     @autodata()
     def test_autodata_decorator_ignores_pandas_dataframe(self, df: pandas.DataFrame):
         self.assertIsNone(df)
 
     @autodata()
-    def test_autodata_decorator_ignores_only_pandas_dataframe(self, text: str, df: pandas.DataFrame):
+    def test_autodata_decorator_ignores_only_pandas_dataframe(
+        self, text: str, df: pandas.DataFrame
+    ):
         self.assertIsNotNone(text)
         self.assertIsNone(df)
